================
SLEPc for Python
================

:Author:       Lisandro Dalcin
:Contact:      dalcinl@gmail.com


Online Documentation
--------------------

+ `User Manual (HTML)`_ (generated with Sphinx_).
+ `User Manual (PDF)`_  (generated with Sphinx_).
+ `API Reference`_      (generated with Epydoc_).

.. _User Manual (HTML): usrman/index.html
.. _User Manual (PDF):  slepc4py.pdf
.. _API Reference:      apiref/index.html

.. _Sphinx:    https://www.sphinx-doc.org/
.. _Epydoc:    http://epydoc.sourceforge.net/


Discussion and Support
----------------------

+ Mailing Lists: petsc-users@mcs.anl.gov, slepc-maint@upv.es


Downloads and Development
-------------------------

+ Project Site:    https://gitlab.com/slepc/slepc
+ Source Releases: https://gitlab.com/slepc/slepc/-/tags/
+ Issue Tracker:   https://gitlab.com/slepc/slepc/issues/
+ Git Repository:  https://gitlab.com/slepc/slepc.git


Citations
---------

If SLEPc for Python been significant to a project that leads to an
academic publication, please acknowledge that fact by citing the
project.

* L. Dalcin, P. Kler, R. Paz, and A. Cosimo,
  *Parallel Distributed Computing using Python*,
  Advances in Water Resources, 34(9):1124-1139, 2011.
  http://dx.doi.org/10.1016/j.advwatres.2011.04.013

* V. Hernandez, J.E. Roman, and V. Vidal,
  *SLEPc: A scalable and flexible toolkit for the solution of eigenvalue problems*,
  ACM Transactions on Mathematical Software, 31(3):351-362, 2005.
  http://dx.doi.org/10.1145/1089014.1089019


Acknowledgments
---------------

This project was partially supported by the
Extreme Computing Research Center (ECRC),
Division of Computer, Electrical, and
Mathematical Sciences & Engineering (CEMSE),
King Abdullah University of Science and Technology (KAUST).
